@@ -1,5 +1,6 @@
 import requests
 import json
+import time
 from typing import List, Dict, Union, Type
 from .manga import Manga, MangaTag
 from .chapter import Chapter
@@ -10,6 +11,8 @@ from .cover import Cover
 from .network import NetworkChapter
 from .search import SearchMapping
 
+INCLUDE_ALL = ["cover_art", "manga", "chapter", "scanlation_group", "author", "artist", "user"]
+
 
 class MDException(Exception):
     pass
@@ -51,6 +54,7 @@ class MangaDex:
         self.login_success = False
         self.session_token = None
         self.refresh_token = None
+        self.rate_limit = 0.25
 
     def login(self, username: str, password: str) -> bool:
         """Logs in to MangaDex using an username and a password."""
@@ -99,9 +103,12 @@ class MangaDex:
             self.session.headers["Authorization"] = resp["token"]["session"]
             return True
 
-    def get_manga(self, uuid: str) -> Manga:
+    def get_manga(self, uuid: str, includes: list = None) -> Manga:
         """Gets a manga with a specific uuid."""
-        req = self.session.get(f"{self.api}/manga/{uuid}")
+        params = None
+        if includes:
+            params = {"includes[]": includes}
+        req = self.session.get(f"{self.api}/manga/{uuid}", params=params)
         if req.status_code == 200:
             resp = req.json()
             return Manga(resp["data"], resp["relationships"], self)
@@ -110,9 +117,12 @@ class MangaDex:
         else:
             raise APIError(req)
 
-    def get_chapter(self, uuid: str) -> Chapter:
+    def get_chapter(self, uuid: str, includes: list = None) -> Chapter:
         """Gets a chapter with a specific uuid."""
-        req = self.session.get(f"{self.api}/chapter/{uuid}")
+        params = None
+        if includes:
+            params = {"includes[]": includes}
+        req = self.session.get(f"{self.api}/chapter/{uuid}", params=params)
         if req.status_code == 200:
             resp = req.json()
             return Chapter(resp["data"], resp["relationships"], self)
@@ -121,13 +131,17 @@ class MangaDex:
         else:
             raise APIError(req)
 
-    def get_chapters(self, ids: List[str]) -> List[Chapter]:
+    def get_chapters(self, ids: List[str], includes: list = None) -> List[Chapter]:
         """Gets chapters with specific uuids."""
         chapters = []
         sub = [ids[x:x+100] for x in range(0, len(ids), 100)]
+        _rem = len(sub)
         for s in sub:
-            p = {"ids[]": s}
+            p = {"ids[]": s, "includes[]": includes}
             req = self.session.get(f"{self.api}/chapter", params=p)
+            _rem -= 1
+            if _rem:
+                time.sleep(self.rate_limit)
             if req.status_code == 200:
                 resp = req.json()
                 chapters += [x for x in resp["results"]]
@@ -139,13 +153,11 @@ class MangaDex:
             raise NoResultsError()
         return [Chapter(x["data"], x["relationships"], self) for x in chapters]
 
-    def get_manga_chapters(self, mg: Manga, params: dict = None) -> List[Chapter]:
+    def get_manga_chapters(self, mg: Manga, params: dict = None, includes: list = None) -> List[Chapter]:
         """Gets chapters associated with a specific Manga."""
         params = params or {}
-        if "limit" in params:
-            params.pop("limit")
-        if "offset" in params:
-            params.pop("offset")
+        if includes:
+            params["includes[]"] = includes
         return self._retrieve_pages(f"{self.api}/manga/{mg.id}/feed", Chapter, call_limit=100, params=params)
 
     def get_manga_covers(self, mg: Manga, params: dict = None) -> List[Cover]:
@@ -202,7 +214,7 @@ class MangaDex:
         req = self.session.get(f"{self.api}/user/{uuid}")
         if req.status_code == 200:
             resp = req.json()
-            return User(resp["data"], self)
+            return User(resp["data"], [], self)
         elif req.status_code == 404:
             raise NoContentError(req)
         else:
@@ -244,7 +256,7 @@ class MangaDex:
             raise APIError(post)
 
     def search(self, obj: str, params: dict,
-               limit: int = 100) -> List[Union[Manga, Chapter, Group, Author, Cover]]:
+               limit: int = 100) -> List[Union[Manga, Chapter, Group, Author, Cover, User]]:
         """Searches an object."""
         m = SearchMapping(obj)
         return self._retrieve_pages(f"{self.api}{m.path}", m.object, limit=limit, call_limit=100, params=params)
@@ -279,6 +291,8 @@ class MangaDex:
                 offset += call_limit
             else:
                 remaining = False
+            if remaining:
+                time.sleep(self.rate_limit)
         if not data:
             raise NoResultsError()
         return [obj(x["data"], x["relationships"], self) for x in data]
